==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/struct_ogre_1_1_hlms_pass_pso.js <==
var struct_ogre_1_1_hlms_pass_pso =
[
    [ "StrongMacroblockBits", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214b", [
      [ "ForceDisableDepthWrites", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214ba10f2c28724fb87cc59179dc26842cb4e", null ],
      [ "InvertVertexWinding", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214bae6f3010b1e71eccd877cad332ef9fc0f", null ],
      [ "NoDepthBuffer", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214ba1b3808a230b60328a8f173dab5038c91", null ]
    ] ],
    [ "hasStrongMacroblock", "struct_ogre_1_1_hlms_pass_pso.html#a9b81b28296baf5d32c06ef3686883339", null ],
    [ "operator!=", "struct_ogre_1_1_hlms_pass_pso.html#ae1ae72c43d27ce38b055ec96a2f8b40f", null ],
    [ "operator<", "struct_ogre_1_1_hlms_pass_pso.html#ac0a8ef4ecbe4fe6014cde50d1e180057", null ],
    [ "operator==", "struct_ogre_1_1_hlms_pass_pso.html#afc4dc599d934e99703dc504c9afaee14", null ],
    [ "adapterId", "struct_ogre_1_1_hlms_pass_pso.html#ab44e93ca2135b4c6cf1b9c7e1e514e7c", null ],
    [ "colourFormat", "struct_ogre_1_1_hlms_pass_pso.html#a3931e31bb2d0b7e23e33b21249a29c40", null ],
    [ "depthFormat", "struct_ogre_1_1_hlms_pass_pso.html#a700f3b53a9344ae0d4089dc723a0e536", null ],
    [ "sampleDescription", "struct_ogre_1_1_hlms_pass_pso.html#a4ee0425ddb698aebcecada4f182565da", null ],
    [ "stencilParams", "struct_ogre_1_1_hlms_pass_pso.html#a9a9b1b99d1cf98165d58ba99a6837549", null ],
    [ "strongMacroblockBits", "struct_ogre_1_1_hlms_pass_pso.html#ac97312e889518a263ee5d7910225b876", null ]
];

==> ogre-next-2.3.0-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/struct_ogre_1_1_hlms_pass_pso.js <==
var struct_ogre_1_1_hlms_pass_pso =
[
    [ "StrongMacroblockBits", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214b", [
      [ "ForceDisableDepthWrites", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214ba10f2c28724fb87cc59179dc26842cb4e", null ],
      [ "InvertVertexWinding", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214bae6f3010b1e71eccd877cad332ef9fc0f", null ],
      [ "NoDepthBuffer", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214ba1b3808a230b60328a8f173dab5038c91", null ],
      [ "ForceDepthClamp", "struct_ogre_1_1_hlms_pass_pso.html#af263ff6f0b338cd6c9e1bfa968a7214bade67d3843f7d123fa303d129c1e79234", null ]
    ] ],
    [ "hasStrongMacroblock", "struct_ogre_1_1_hlms_pass_pso.html#a9b81b28296baf5d32c06ef3686883339", null ],
    [ "operator!=", "struct_ogre_1_1_hlms_pass_pso.html#ae1ae72c43d27ce38b055ec96a2f8b40f", null ],
    [ "operator<", "struct_ogre_1_1_hlms_pass_pso.html#ac0a8ef4ecbe4fe6014cde50d1e180057", null ],
    [ "operator==", "struct_ogre_1_1_hlms_pass_pso.html#afc4dc599d934e99703dc504c9afaee14", null ],
    [ "adapterId", "struct_ogre_1_1_hlms_pass_pso.html#ab44e93ca2135b4c6cf1b9c7e1e514e7c", null ],
    [ "colourFormat", "struct_ogre_1_1_hlms_pass_pso.html#a3931e31bb2d0b7e23e33b21249a29c40", null ],
    [ "depthFormat", "struct_ogre_1_1_hlms_pass_pso.html#a700f3b53a9344ae0d4089dc723a0e536", null ],
    [ "resolveColourFormat", "struct_ogre_1_1_hlms_pass_pso.html#a0eb4945bc9aa5f3a9b83bfcf1a758ae9", null ],
    [ "sampleDescription", "struct_ogre_1_1_hlms_pass_pso.html#a4ee0425ddb698aebcecada4f182565da", null ],
    [ "stencilParams", "struct_ogre_1_1_hlms_pass_pso.html#a9a9b1b99d1cf98165d58ba99a6837549", null ],
    [ "strongMacroblockBits", "struct_ogre_1_1_hlms_pass_pso.html#ac97312e889518a263ee5d7910225b876", null ]
];
